aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/core_ext/array/conversions.rb
diff options
context:
space:
mode:
Diffstat (limited to 'activesupport/lib/active_support/core_ext/array/conversions.rb')
-rw-r--r--activesupport/lib/active_support/core_ext/array/conversions.rb20
1 files changed, 14 insertions, 6 deletions
diff --git a/activesupport/lib/active_support/core_ext/array/conversions.rb b/activesupport/lib/active_support/core_ext/array/conversions.rb
index 19220da2b1..e9e9cf445e 100644
--- a/activesupport/lib/active_support/core_ext/array/conversions.rb
+++ b/activesupport/lib/active_support/core_ext/array/conversions.rb
@@ -3,12 +3,20 @@ module ActiveSupport #:nodoc:
module Array #:nodoc:
# Enables to conversion of Arrays to human readable lists. ['one', 'two', 'three'] => "one, two, and three"
module Conversions
- # Converts the array to comma-seperated sentence where the last element is joined by the connector word (default is 'and').
- def to_sentence(connector = 'and')
- if length > 1
- "#{self[0...-1].join(', ')}, #{connector} #{self[-1]}"
- elsif length == 1
- self[0]
+ # Converts the array to comma-seperated sentence where the last element is joined by the connector word. Options:
+ # * <tt>:connector</tt>: The word used to join the last element in arrays with more than two elements (default: "and")
+ # * <tt>:skip_last_comma</tt>: Set to true to return "a, b and c" instead of "a, b, and c".
+ def to_sentence(options = {})
+ options.assert_valid_keys(:connector, :skip_last_comma)
+ options.reverse_merge! :connector => 'and', :skip_last_comma => false
+
+ case length
+ when 1
+ self[0]
+ when 2
+ "#{self[0]} #{options[:connector]} #{self[1]}"
+ else
+ "#{self[0...-1].join(', ')}#{options[:skip_last_comma] ? '' : ','} #{options[:connector]} #{self[-1]}"
end
end